﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace WriteLogSplitCommands
{
    public class ShortcutProcessor : WriteLogShortcutHelper.ShortcutHelper
    {
       /* These are the names of the commands as they will appear
           in WriteLog's Keyboard Shortcuts "Command to run" list: */
        string[] CommandNames = new string[] {
                "Save TX freq",  // this is which == 0
                "Split msg 01",  
                "Split msg 02",  
                "Split msg 03",  
                "Split msg 04",  
                "Split msg 05",  
                "Split msg 06",  
                "Split msg 07",  
                "Split msg 08",  
                "Split msg 09",  
                "Split msg 10", 
 
                // They will appear in WriteLog with "External:" prepended.
                // Look in the E's in that menu.
        };
 
        // you must have this property
        public override int ShortcutCount
        {            get { return CommandNames.Length; }         }
 
        // and you must have this one
        public override string this[int which]
        {
            get {
                if ((which < 0) || (which >= CommandNames.Length))
                    throw new IndexOutOfRangeException();
                return CommandNames[which];
            }
        }

        private short m_mode;
        private double m_rxFreq;
        private double m_txFreq;
        private short m_split;

        // and you must have this method
        public override void InvokeShortcut(int which, WriteLogClrTypes.IWriteL wl)
        {
            if ((which < 0) || (which >= CommandNames.Length))
                throw new IndexOutOfRangeException();
 
            // you can call methods on the wl object here.
            WriteLogClrTypes.ISingleEntry currentEntry = 
                wl.GetCurrentEntry() as WriteLogClrTypes.ISingleEntry;
            switch (which)
            {
                case 0: // Read the rig as split now and save it away
                    currentEntry.GetLogFrequency(ref m_mode, ref m_rxFreq, ref m_txFreq, ref m_split);
                    break;

                case 1:
                case 2:
                case 3:
                case 4:
                case 5:
                case 6:
                case 7:
                case 8:
                case 9:
                case 10:
                    {
                        if (m_txFreq == 0) // the set command hasn't happened yet
                            return;

                        // read what the rig is now
                        short mode=0; double rxFreq=0; double txFreq=0; short split=0;
                        currentEntry.GetLogFrequency(ref mode, ref rxFreq, ref txFreq, ref split);
                        // set the rig. Keep the mode/rxfreq we just read, but set txfreq and split per saved
                        currentEntry.SetLogFrequencyEx(mode, rxFreq, m_txFreq, m_split);

                        // this is ugly. WriteLog takes some time to actually reset the rig
                        int MillisecToWaitForRig = 100; // not all rigs take the same time
                        System.DateTime wait = System.DateTime.Now.AddMilliseconds(MillisecToWaitForRig);
                        while (System.DateTime.Now < wait)
                            System.Windows.Forms.Application.DoEvents();

                        // now invoke the phone message command
                        string command = string.Format("Message{0:00}", which);
                        wl.InvokeKeyboardCommand(command);
                    }
                    break;
            }
        }
     }
}
